/**
 * misc.c - Miscellaneous functions. Part of the Linux-NTFS project.
 *
 * Copyright (c) 2006 Szabolcs Szakacsits
 *
 * This program/include file is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as published
 * by the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program/include file is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program (in the main directory of the Linux-NTFS
 * distribution in the file COPYING); if not, write to the Free Software
 * Foundation,Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#ifdef HAVE_STDLIB_H
#include <stdlib.h>
#endif

#include "support.h"
#include "logging.h"

/**
 * ntfs_calloc - A logging supported calloc(3)
 * 
 * Return a pointer to the allocated memory or NULL if the request fails.
 * Memory is initialized with zeros.
 */
void *ntfs_calloc(size_t size)
{
	void *p;

	p = calloc(1, size);
	if (!p)
		ntfs_log_perror("Failed to calloc %lld bytes", (long long)size);
	return p;
}

/**
 * ntfs_malloc - A logging supported malloc(3)
 * 
 * Return a pointer to the allocated memory or NULL if the request fails.
 * Memory is uninitialized.
 */
void *ntfs_malloc(size_t size)
{
	void *p;

	p = malloc(size);
	if (!p)
		ntfs_log_perror("Failed to malloc %lld bytes", (long long)size);
	return p;
}
